
.ap_width .ap_title{
  -ms-transform:rotate(270deg); /* IE 9 */
  -moz-transform:rotate(270deg); /* Firefox */
  -webkit-transform:rotate(270deg); /* Safari and Chrome */
  -o-transform:rotate(270deg); /* Opera */	
   margin-top: 75%;
  color: #FFFFFF;
  font-size: 165%;

}

.ap_width .ap_icon {
    margin: 10% 0;
    max-height: 30%;
    text-align: center;
    overflow: hidden;
    height: 130px;
}

.ap_width_min .ap_title{
  -ms-transform:rotate(270deg); /* IE 9 */
  -moz-transform:rotate(270deg); /* Firefox */
  -webkit-transform:rotate(270deg); /* Safari and Chrome */
  -o-transform:rotate(270deg); /* Opera */	
   margin-top: 75%;
  color: #FFFFFF;
  font-size: 86%;
  /*height: 90px; */

}


.ap_width .ap_icon {
    height: 130px;
    margin: 10% 20%;
    max-height: 150px;
    max-width: 150px;
    overflow: hidden;
    text-align: center;
}
.ap_height .ap_title{
    color: #FFFFFF;
    float: left;
    font-size: 1.5em;
    margin: 20% 3%;

}

.ap_height .ap_icon {
    overflow: hidden;
    text-align: center;
}


.ap_height_min .ap_title{
    color: #FFFFFF;
    display: block;
    font-size: 1em;
    margin: 2% 3%;
    text-align: center;

}

@media only screen 
and (max-width: 600px) {
	.ap_height_min .ap_title{
		font-size: 0.5em;
	}
}
@media only screen 
and (max-height: 350px) {
	.ap_width .ap_title{
		font-size: 0.7em;
	}
}

.ap_height_min .ap_icon {
    display: block;
    overflow: hidden !important;
    text-align: center;
}
.ap_height_min .ap_plug {
	display: table-cell;
}

.no_pad{
	padding: 0px!important;
	/*max-width: 1362px!important;*/
}


@media only screen 
and (max-width: 320px) {
	.ap_width_min .ap_title {
    color: #ffffff;
    font-size: 60%;
    margin-top: 110%;
    transform: rotate(270deg);
    transform-origin: 0 0;
   -webkit-transform-origin:0 0 ;
	}

}

.ap_presentation {

	display: inline-block;
}


.ap_width .ap_plug{
	float:left;
}

.ap_width  .ap_slide{
	float:left;
}

.ap_width_min .ap_plug{
	float:left;
}

.ap_width_min  .ap_slide{
	float:left;
}

.ap_height .ap_plug{
	display: table-cell;
}



.ap_height  .ap_slide{
	float:table-cell;
}


.ap_icon > img {
    max-height: 150px;
    max-width: 150px;
}

@media only screen 
and (max-height: 600px) {
	.ap_icon > img {
	    max-height: 50px;
	    max-width: 50px;
	}
}

.ap_content{
	width: 100%;
	height: 100%;	
}

.cycle-overlay {
    background: none repeat scroll 0 0 black;
    bottom: 0;
    color: white;
    opacity: 0.6;
    padding: 15px;
    position: absolute;
}

.ap_content a{
	 text-decoration: none;
}
